@@ -2,7 +2,7 @@ package SVG::Manual;
 use strict;
 use warnings;
 
-our $VERSION = 2.51;
+our $VERSION = '2.54';
 
 =head1 NAME
 
@@ -20,8 +20,6 @@ Covers SVG-2.51 distribution, 30 March 2012
 
     # create an SVG object
     my $svg= SVG->new(width=>200,height=>200);
-    #or
-    my $svg= SVG->new(width=>200,height=>200);
 
     # use explicit element constructor to generate a group element
     my $y=$svg->group(
@@ -203,10 +201,8 @@ Resulting XML snippet:
 
 =head1 SEE ALSO
 
-perl(1), L<SVG::XML>, L<SVG::Element>, L<SVG::DOM>, L<SVG::Parser>
 L<http://www.roitsystems.com/>ROIT Systems: Commercial SVG perl solutions
 L<http://www.w3c.org/Graphics/SVG/>SVG at the W3C
-	
 
 =head1 AUTHOR
 
@@ -327,7 +323,7 @@ as a child.
 
 B<Example:>
 
-    # generate an anchor	
+    # generate an anchor
     $tag = $svg->anchor(
         -href=>'http://here.com/some/simpler/svg.svg'
     );
@@ -776,6 +772,7 @@ $svg->mouseaction(%attributes)
 
 Sets/Adds mouse action definitions for tag
 
+=head2 attrib
 
 $svg->attrib($name, $value)
 
